Allow 200 as a response from /v2/zone/recordsets
Designate can return a 200 or a 202, depending on the status
of an API call.
This allows tempest to accept the 200
Change-Id: I0e9c38bb8f11f7c9ee31d4f7eb710b7df30674df
diff --git a/designate_tempest_plugin/services/dns/v2/json/recordset_client.py b/designate_tempest_plugin/services/dns/v2/json/recordset_client.py
index 28ec56a..578ccf3 100644
--- a/designate_tempest_plugin/services/dns/v2/json/recordset_client.py
+++ b/designate_tempest_plugin/services/dns/v2/json/recordset_client.py
@@ -60,8 +60,9 @@
'zones/{0}/recordsets'.format(zone_uuid), recordset_uuid,
data=recordet_data, params=params)
- # Update Recordset should Return a HTTP 202
- self.expected_success(202, resp.status)
+ # Update Recordset should Return a HTTP 202, or a 200 if the recordset
+ # is already active
+ self.expected_success([200, 202], resp.status)
return resp, body